@@ -1,4 +1,4 @@
-// Copyright (c) 2017-2022, University of Tennessee. All rights reserved.
+// Copyright (c) 2017-2023, University of Tennessee. All rights reserved.
 // SPDX-License-Identifier: BSD-3-Clause
 // This program is free software: you can redistribute it and/or modify it under
 // the terms of the BSD 3-Clause license. See the accompanying LICENSE file.
@@ -69,9 +69,6 @@ int64_t sysvx(
         berr,
         qry_work, &ineg_one,
         qry_iwork, &info_
-        #ifdef LAPACK_FORTRAN_STRLEN_END
-        , 1, 1
-        #endif
     );
     if (info_ < 0) {
         throw Error();
@@ -93,9 +90,6 @@ int64_t sysvx(
         berr,
         &work[0], &lwork_,
         &iwork[0], &info_
-        #ifdef LAPACK_FORTRAN_STRLEN_END
-        , 1, 1
-        #endif
     );
     if (info_ < 0) {
         throw Error();
@@ -160,9 +154,6 @@ int64_t sysvx(
         berr,
         qry_work, &ineg_one,
         qry_iwork, &info_
-        #ifdef LAPACK_FORTRAN_STRLEN_END
-        , 1, 1
-        #endif
     );
     if (info_ < 0) {
         throw Error();
@@ -184,9 +175,6 @@ int64_t sysvx(
         berr,
         &work[0], &lwork_,
         &iwork[0], &info_
-        #ifdef LAPACK_FORTRAN_STRLEN_END
-        , 1, 1
-        #endif
     );
     if (info_ < 0) {
         throw Error();
@@ -251,9 +239,6 @@ int64_t sysvx(
         berr,
         (lapack_complex_float*) qry_work, &ineg_one,
         qry_rwork, &info_
-        #ifdef LAPACK_FORTRAN_STRLEN_END
-        , 1, 1
-        #endif
     );
     if (info_ < 0) {
         throw Error();
@@ -275,9 +260,6 @@ int64_t sysvx(
         berr,
         (lapack_complex_float*) &work[0], &lwork_,
         &rwork[0], &info_
-        #ifdef LAPACK_FORTRAN_STRLEN_END
-        , 1, 1
-        #endif
     );
     if (info_ < 0) {
         throw Error();
@@ -477,9 +459,6 @@ int64_t sysvx(
         berr,
         (lapack_complex_double*) qry_work, &ineg_one,
         qry_rwork, &info_
-        #ifdef LAPACK_FORTRAN_STRLEN_END
-        , 1, 1
-        #endif
     );
     if (info_ < 0) {
         throw Error();
@@ -501,9 +480,6 @@ int64_t sysvx(
         berr,
         (lapack_complex_double*) &work[0], &lwork_,
         &rwork[0], &info_
-        #ifdef LAPACK_FORTRAN_STRLEN_END
-        , 1, 1
-        #endif
     );
     if (info_ < 0) {
         throw Error();
